bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 34. Aventiure
___________________________________________________
###### 2064 | ### Die herren nach ir mvede gesazen do zetal ### Volker vn– Hagene die giengen fvr den sal ### sich leinten vf die schilde die vbermvten man ### da wart rede genvoge von in beiden getan
###### 2065 | ### Do sprach von Burgonden Giselher der degen ### iane mvegt ir lieben frivnde niht rowe noch gepflegen ### ir svlt die toten lvte vz dem hvse tragen ### wir werden noch bestanden ich wilz iv wærliche sagen
###### 2066 | ### So wol mich solhes herren sprach do Hagene ### der rat enzæme niemen wan eime degene ### den vns min ivnger herre hivte hat getan ### des mvgt ir Bvrgonden alle vroeliche stan
| ### Do volgeten si dem kinde vn– trvgen fvr die tver ### wol zwei tvsent toten wrfen si derfver ### vor des sales stiegen vielen si zetal ### do hvop sich von ir mâgen ein vil klagelicher schal
###### 2068 | ### Ez was ir etelicher so mæzliche wnt ### der sin mit helfe pflæge er wrde noch gesvnt ### der von dem hohem valle mvse ligen tot ### die klagten do ir frivnde des twanch si iamerhaftiv not
###### 2069 | ### Do sprach der videlære ein reche vil gemeit ### nv chivse ich des die wareheit als ma mir hat gesæit ### die Hvnen sint vil boese si chlagent sam div wip ### nv solden si bervchen der vil sere wnder lip
###### 2070 | ### Do wande ein marcgrave er reit ez dvrch gvot ### er sach einen sinen mach gevallen in daz blvot ### er besloz in mit den armen vn– wolde in tragen dan ### den schoz ob im ze tode der vil chvne spileman
###### 2071 | ### Do dandern daz gesahen div flvht hvp sich von dan ### si begvnden alle flvchen dem selben spileman ### noh hvob er vnder fvzen einen ger vil hart ### der von eime Hvnen in daz hvs geschozzen wart
###### 2072 | ### Den schoz er do hin widere dvrch die bvrch dan ### mit siner chraft so verre den Ezelen man ### gaber herberge vof hoher von dem sal ### daz sin vil starchez ellen die lvte vorhten vber al
| ### Do stvnden vor dem hvose Ezel vn– sine man ### Volker vn– Hagene reden do began ### mit der Hvnen kvnige ir willen vn– mvot ### des chomen sit in sorgen die helede chven vn– gvot
###### 2074 | ### Ez zæme so sprach Hagene vil wol volches trost ### daz die herren væhten zaller vorderost ### also der kvnec Gvnther vnde Gernot hie tvot ### die howent dvrch die helme nach swerten vlvzet daz blvot
###### 2075 | ### Ezele was so chvne er vazzete sinen schilt ### nv vart gewærliche sprach min frov Chriemh' ### vn– bietet ir den rechen daz golt vber rant ### wan erreichet ivch dort Hagene ir habt den tot an der hant
###### 2076 | ### Done wolde der kvnec here des strites erwinden niht ### daz von so ri[74v]chen fvrsten selten nv geschiht ### man mvos in bi dem <vezzil> wider ziehen dan ### Hagene der grimme sin spotten aber began
###### 2077 | ### Ez was ein nahiv sippe sprach do Hagene ### die Sivrit vn– Ezele <heten> zesamene ### er minnete Chriemh' ê si ie gesæhe dich ### kvnic vil boese warvmbe rætest an mich
| ### Dise rede horte wol des kvniges wip ### des wart vil vnmvtes der Chriemh' lip ### daz er si torste schelten vor Ezelen man ### dar vmbe si aber raten an die geste began
###### 2079 | ### Si sprach der mir von Tronegen Hagenen slvege ### vn– mir sin hovbet ze gibe trvge ### dem fvlt ich rotes goldes den Ezeln rant ### ovch gæb ich im ze miete vil gvte bvrge vn– lant
###### 2080 | ### Nvne weiz ich wes si bitent sprach der spileman ### ine gesach nie helde mere so zageliche stan ### da man horte bieten so rehte richen solt ### si mohten gerne dienen die bvrge vn– ovch daz rote golt
###### 2081 | ### Ezele der vil riche hete iamer vn– not ### er klagte pitterliche mage vn– manne tot ### da stvnt von manigen landen vil rechen gemeit ### die weinten mit dem kvnige siniv chreftigen leit
###### 2082 | ### Des begvnde spotten der kvne Volker ### ich sihe hie sere weinen vil manigen rechen her ### si gestent ir herren vbele in siner starchen not ### ia ezzent si mit schanden nv vil lange hie sin brot
###### 2083 | ### Do gedahten in die besten er hat vns war geseit ### doch enwas ez da niemen so hercenliche leit ### als ovch Iringe dem helede vz Tenelant ### daz man in churcen citen mit der wareheite wol bevant

<<< Übersicht <<< vorige Seite nächste Seite >>>